Module central

Modules

characteristic
descriptor
peripheral
service

Structs

AdvertisementData
Peripheral’s advertisement data.
CentralManager
An object that scans for, discovers, connects to, and manages peripherals.
ScanOptions
Peripheral scanning options accepted by scan_with_options.
ServiceData
Service-specific advertisement data. The keys represent Service UUIDs.

Enums

CentralEvent
Events that a central manager sends about changes in its state or state of its local or remote components.