Enum AttErrorKind

#[non_exhaustive]
pub enum AttErrorKind {
Show 19 variants Other, Success, InvalidHandle, ReadNotPermitted, WriteNotPermitted, InvalidPdu, InsufficientAuthentication, RequestNotSupported, InvalidOffset, InsufficientAuthorization, PrepareQueueFull, AttributeNotFound, AttributeNotLong, InsufficientEncryptionKeySize, InvalidAttributeValueLength, UnlikelyError, InsufficientEncryption, UnsupportedGroupType, InsufficientResources,
}
The possible errors returned by a GATT server (a remote peripheral) during Bluetooth low energy ATT transactions.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Other

ATT error that didn’t map to any of the existing variants.



Success

The ATT command or request successfully completed.



InvalidHandle

The attribute handle is invalid on this peripheral.



ReadNotPermitted

The permissions prohibit reading the attribute’s value.



WriteNotPermitted

The permissions prohibit writing the attribute’s value.



InvalidPdu

The attribute Protocol Data Unit (PDU) is invalid.



InsufficientAuthentication

Reading or writing the attribute’s value failed for lack of authentication.



RequestNotSupported

The attribute server doesn’t support the request received from the client.



InvalidOffset

The specified offset value was past the end of the attribute’s value.



InsufficientAuthorization

Reading or writing the attribute’s value failed for lack of authorization.



PrepareQueueFull

The prepare queue is full, as a result of there being too many write requests in the queue.



AttributeNotFound

The attribute wasn’t found within the specified attribute handle range.



AttributeNotLong

The ATT read blob request can’t read or write the attribute.



InsufficientEncryptionKeySize

The encryption key size used for encrypting this link is insufficient.



InvalidAttributeValueLength

The length of the attribute’s value is invalid for the intended operation.



UnlikelyError

The ATT request encountered an unlikely error and wasn’t completed.



InsufficientEncryption

Reading or writing the attribute’s value failed for lack of encryption.



UnsupportedGroupType

The attribute type isn’t a supported grouping attribute as defined by a higher-layer specification.



InsufficientResources

Resources are insufficient to complete the ATT request.